aboutsummaryrefslogtreecommitdiffstats
path: root/archive
diff options
context:
space:
mode:
authorDon Williams <don.e.williams@gmail.com>2026-02-13 14:40:51 -0500
committerDon Williams <don.e.williams@gmail.com>2026-02-13 14:40:51 -0500
commit62f364ed911bff31aa1abc307322f7270aa0aff0 (patch)
tree7cb4d055d3bc4efbdb9ba261970d37307a6dae8a /archive
parent9910e59796be08f84de5fe87bcaaebc807d5fce0 (diff)
Migrate Jakoolit to Linuxbeginnings repo references
Diffstat (limited to 'archive')
-rwxr-xr-xarchive/release.sh20
-rwxr-xr-xarchive/upgrade.sh2
2 files changed, 11 insertions, 11 deletions
diff --git a/archive/upgrade.sh b/archive/upgrade.sh
index 45624c4f..63375762 100755
--- a/archive/upgrade.sh
+++ b/archive/upgrade.sh
@@ -1,5 +1,5 @@
#!/usr/bin/env bash
-# /* ---- 💫 https://github.com/JaKooLit 💫 ---- */ #
+# /* ---- 💫 https://github.com/LinuxBeginnings 💫 ---- */ #
# for Semi-Manual upgrading your system.
# NOTE: requires rsync
send patches to the email below
yukais@pinapelz.com
include the subject [PATCH repo_name]
pinapelz.com
homepage
diff --git a/archive/release.sh b/archive/release.sh
index e29eaa79..78df3444 100755
--- a/archive/release.sh
+++ b/archive/release.sh
@@ -1,5 +1,5 @@
#!/usr/bin/env bash
-# /* ---- 💫 https://github.com/JaKooLit 💫 ---- */ #
+# /* ---- 💫 https://github.com/LinuxBeginnings 💫 ---- */ #
# For downloading dots from releases
# Set some colors for output messages
@@ -78,7 +78,7 @@ if [ -f Hyprland-Dots.tar.gz ]; then
existing_version=$(echo Hyprland-Dots.tar.gz | grep -oP 'v\d+\.\d+\.\d+' | sed 's/v//')
# Fetch the tag_name for the latest release using the GitHub API
- latest_version=$(curl -s https://api.github.com/repos/JaKooLit/Hyprland-Dots/releases/latest | grep "tag_name" | cut -d '"' -f 4 | sed 's/v//')
+ latest_version=$(curl -s https://api.github.com/repos/LinuxBeginnings/Hyprland-Dots/releases/latest | grep "tag_name" | cut -d '"' -f 4 | sed 's/v//')
# Check if versions match
if [ "$existing_version" = "$latest_version" ]; then
@@ -94,8 +94,8 @@ if [ -f Hyprland-Dots.tar.gz ]; then
if [ "$upgrade_choice" = "y" ]; then
echo -e "${NOTE} Proceeding to download the latest release."
- # Delete existing directories starting with JaKooLit-Hyprland-Dots
- find . -type d -name 'JaKooLit-Hyprland-Dots*' -exec rm -rf {} +
+ # Delete existing directories starting with LinuxBeginnings-Hyprland-Dots
+ find . -type d -name 'LinuxBeginnings-Hyprland-Dots*' -exec rm -rf {} +
rm -f Hyprland-Dots.tar.gz
printf "${WARN} Removed existing Hyprland-Dots.tar.gz.\n"
else
@@ -108,7 +108,7 @@ fi
printf "${NOTE} Downloading the latest Hyprland source code release...\n"
# Fetch the tag name for the latest release using the GitHub API
-latest_tag=$(curl -s https://api.github.com/repos/JaKooLit/Hyprland-Dots/releases/latest | grep "tag_name" | cut -d '"' -f 4)
+latest_tag=$(curl -s https://api.github.com/repos/LinuxBeginnings/Hyprland-Dots/releases/latest | grep "tag_name" | cut -d '"' -f 4)
# Check if the tag is obtained successfully
if [ -z "$latest_tag" ]; then
@@ -117,7 +117,7 @@ if [ -z "$latest_tag" ]; then
fi
# Fetch the tarball URL for the latest release using the GitHub API
-latest_tarball_url=$(curl -s https://api.github.com/repos/JaKooLit/Hyprland-Dots/releases/latest | grep "tarball_url" | cut -d '"' -f 4)
+latest_tarball_url=$(curl -s https://api.github.com/repos/LinuxBeginnings/Hyprland-Dots/releases/latest | grep "tarball_url" | cut -d '"' -f 4)
# Check if the URL is obtained successfully
if [ -z "$latest_tarball_url" ]; then
@@ -134,15 +134,15 @@ if curl -L "$latest_tarball_url" -o "$file_name"; then
tar -xzf "$file_name" || exit 1
# delete existing Hyprland-Dots
- rm -rf JaKooLit-Hyprland-Dots
+ rm -rf LinuxBeginnings-Hyprland-Dots
# Identify the extracted directory
extracted_directory=$(tar -tf "$file_name" | grep -o '^[^/]\+' | uniq)
- # Rename the extracted directory to JaKooLit-Hyprland-Dots
- mv "$extracted_directory" JaKooLit-Hyprland-Dots || exit 1
+ # Rename the extracted directory to LinuxBeginnings-Hyprland-Dots
+ mv "$extracted_directory" LinuxBeginnings-Hyprland-Dots || exit 1
- cd "JaKooLit-Hyprland-Dots" || exit 1
+ cd "LinuxBeginnings-Hyprland-Dots" || exit 1
# Set execute permission for copy.sh and execute it
chmod +x copy.sh